﻿using System;
using System.IO;
using System.Windows.Media.Imaging;
using System.Xml.Serialization;

namespace DataOperations
{
    /// <summary>
    /// 
    /// </summary>
    public class Movie
    {
        private string movieTitle;
        private string movieRating;
        private string movieGenre;
        private string audienceRating;
        private string cast;
        private string director;
        private string year;
        private string duration;
        private string base64Image;
        private BitmapImage bitmap;

        private bool durationFormatted;
        private bool titleFormatted;

        /// <summary>
        /// Initializes a new instance of the <see cref="Movie" /> class.
        /// </summary>
        public Movie()
        {
        }

        /// <summary>
        /// Gets or sets the ranking of the movie.
        /// </summary>
        /// <value>The ranking.</value>
        [XmlIgnore]
        public int Ranking
        {
            get;
            set;
        }

        /// <summary>
        /// Gets the bitmap.
        /// </summary>
        /// <value>The bitmap.</value>
        [XmlIgnore]
        public BitmapImage Bitmap
        {
            get
            {
                if (this.bitmap == null && !string.IsNullOrEmpty(this.base64Image))
                {
                    byte[] imageBytes = System.Convert.FromBase64String(this.base64Image);
                    BitmapImage img = new BitmapImage();
                    img.SetSource(new MemoryStream(imageBytes));
                    this.bitmap = img;
                }
                return this.bitmap;
            }
        }

        /// <summary>
        /// Gets or sets the duration.
        /// </summary>
        /// <value>The duration.</value>
        public string Duration
        {
            get
            {
                if (!this.durationFormatted)
                {
                    if (this.duration == "N/A")
                    {
                        this.durationFormatted = true;
                    }
                    else
                    {
                        TimeSpan duration = TimeSpan.FromSeconds(int.Parse(this.duration));
                        this.duration = string.Format("{0}h {1}min", duration.Hours, duration.Minutes);
                        this.durationFormatted = true;
                    }
                }

                return this.duration;

            }
            set
            {
                this.duration = value;
            }
        }

        /// <summary>
        /// Gets or sets the year.
        /// </summary>
        /// <value>The year.</value>
        public string Year
        {
            get
            {
                return this.year;
            }
            set
            {
                this.year = value;
            }
        }

        /// <summary>
        /// Gets or sets the title.
        /// </summary>
        /// <value>The title.</value>
        public string Title
        {
            get
            {
                if (!this.titleFormatted)
                {
                    this.movieTitle = this.movieTitle.ToUpper();
                    this.titleFormatted = true;
                }
                return this.movieTitle;
            }
            set
            {
                this.movieTitle = value;
            }
        }

        /// <summary>
        /// Gets or sets the rating.
        /// </summary>
        /// <value>The rating.</value>
        public string Rating
        {
            get
            {
                return this.movieRating;
            }
            set
            {
                this.movieRating = value;
            }
        }

        /// <summary>
        /// Gets or sets the audience rating.
        /// </summary>
        /// <value>The audience rating.</value>
        public string AudienceRating
        {
            get
            {
                return this.audienceRating;
            }
            set 
            {
                this.audienceRating = value;
            }
        }

        /// <summary>
        /// Gets or sets the genre.
        /// </summary>
        /// <value>The genre.</value>
        public string Genre
        {
            get
            {
                return this.movieGenre;
            }
            set
            {
                this.movieGenre = value;
            }
        }

        /// <summary>
        /// Gets or sets the cast.
        /// </summary>
        /// <value>The cast.</value>
        public string Cast
        {
            get
            {
                return this.cast;
            }
            set
            {
                this.cast = value;
            }
        }

        /// <summary>
        /// Gets or sets the director.
        /// </summary>
        /// <value>The director.</value>
        public string Director
        {
            get
            {
                return this.director;
            }
            set
            {
                this.director = value;
            }
        }

        /// <summary>
        /// Gets or sets the base64 image.
        /// </summary>
        /// <value>The base64 image.</value>
        public string Base64Image
        {
            get
            {
                return this.base64Image;
            }
            set
            {
                this.base64Image = value;
            }
        }

		public string Summary
		{
			get
			{ 
				return String.Format("{0} - {1} - {2} ", this.Rating, this.Year, this.Duration);
			}
		}
    }
}
